@@ -4,7 +4,6 @@ from django.contrib import admin
 from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse
 from django.http import HttpResponseForbidden, HttpResponseRedirect
-from django.test.client import Client
 from hvad.admin import InlineModelForm
 from hvad.admin import translatable_modelform_factory
 from hvad.forms import TranslatableModelForm
@@ -14,7 +13,7 @@ from hvad.test_utils.fixtures import (TwoTranslatedNormalMixin, SuperuserMixin,
 from hvad.test_utils.request_factory import RequestFactory
 from hvad.test_utils.testcase import NaniTestCase
 from hvad.test_utils.context_managers import SettingsOverride
-from testproject.app.models import Normal, SimpleRelated, Other
+from hvad.test_utils.project.app.models import Normal, SimpleRelated, Other
 
 class BaseAdminTests(object):
     def _get_admin(self, model):
@@ -33,20 +32,39 @@ class NormalAdminTests(NaniTestCase, BaseAdminTests, SuperuserMixin):
         normal_si = Normal.objects.get(pk=normal.pk).translate('sl')
         normal_si.translated_field = slovenian_string
         normal_si.save()
-
+        
+        english_string = u'English test string'
+        default = Normal.objects.language("en").create(
+            shared_field = "shared field",
+            translated_field = english_string,
+        )
+        default_si = Normal.objects.get(pk=normal.pk).translate('us-en')
+        default_si.translated_field = english_string
+        default_si.save()
 
         Other.objects.create(normal=normal)
         self.assertEqual(normal.lazy_translation_getter("translated_field"), translated_field_value)
-        n2 =  Normal.objects.get(pk=normal.pk)
-        self.assertEqual(n2.safe_translation_getter("translated_field"), None)
-        self.assertEqual(n2.lazy_translation_getter("translated_field"), translated_field_value)
-        self.assertEqual(n2.safe_translation_getter("translated_field"), translated_field_value)
+
+        with LanguageOverride('da'):
+            n2 =  Normal.objects.get(pk=normal.pk)
+            self.assertEqual(n2.safe_translation_getter("translated_field"), None)
+            self.assertEqual(n2.lazy_translation_getter("translated_field"), translated_field_value)
+            self.assertEqual(n2.safe_translation_getter("translated_field"), translated_field_value)
 
         with LanguageOverride('sl'):
             n2 =  Normal.objects.get(pk=normal.pk)
             self.assertEqual(n2.safe_translation_getter("translated_field"), None)
             self.assertEqual(n2.lazy_translation_getter("translated_field"), slovenian_string)
             self.assertEqual(n2.safe_translation_getter("translated_field"), slovenian_string)
+        
+        # This tests a langauge that we do not currently have, so don't add Japanese translations, please.
+        with LanguageOverride('jp'):
+            n2 = Normal.objects.get(pk=normal.pk)
+            self.assertEqual(n2.safe_translation_getter("translated_field"), None)
+            self.assertEqual(n2.lazy_translation_getter("translated_field"), english_string)
+            # This should work because when 'jp' isn't found, it will then try
+            # the default language, which is en, in this case.
+            self.assertEqual(n2.safe_translation_getter("translated_field"), english_string)
 
     def test_all_translations(self):
         # Create an unstranslated model and get the translations
@@ -471,4 +489,4 @@ class TranslatableInlineAdminTests(NaniTestCase, BaseAdminTests, SuperuserMixin)
                         model = SimpleRelated
                 form = ExampleInlineForm(instance=instance)
 
-                self.assertTrue(form.initial["id"] == instance.id)
\ No newline at end of file
+                self.assertTrue(form.initial["id"] == instance.id)
