@@ -1,7 +1,7 @@
 from hvad.test_utils.data import DATES_REVERSED, D3
 from hvad.test_utils.fixtures import DatesMixin
 from hvad.test_utils.testcase import NaniTestCase
-from testproject.app.models import Date
+from hvad.test_utils.project.app.models import Date
 import datetime
 
 class LatestTests(NaniTestCase, DatesMixin):
@@ -21,4 +21,4 @@ class DatesTests(NaniTestCase, DatesMixin):
         self.assertEqual(len(Date.objects.language('en').dates("shared_date", "year")), 2)
         self.assertEqual(len(Date.objects.language('en').dates("shared_date", "month")), 3)
         self.assertEqual(len(Date.objects.language('en').dates("shared_date", "day")), 3)
-        self.assertEqual(len(Date.objects.language('en').dates("shared_date", "day").filter(shared_date__gt=d2011)), 2)
\ No newline at end of file
+        self.assertEqual(len(Date.objects.language('en').dates("shared_date", "day").filter(shared_date__gt=d2011)), 2)
