@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from hvad.fieldtranslator import translate
 from hvad.test_utils.testcase import NaniTestCase
-from testproject.app.models import Related
+from hvad.test_utils.project.app.models import Related
 
 
 class FieldtranslatorTests(NaniTestCase):
@@ -19,4 +19,4 @@ class FieldtranslatorTests(NaniTestCase):
         INPUT = 'normal__translated_field__exact'
         query_string, joins = translate(INPUT, Related)
         self.assertEqual(query_string, 'normal__translations__translated_field__exact')
-        self.assertEqual(joins, ['normal__translations__language_code'])
\ No newline at end of file
+        self.assertEqual(joins, ['normal__translations__language_code'])
