@@ -1,12 +1,10 @@
 # -*- coding: utf-8 -*-
 from hvad.admin import TranslatableModelAdminMixin
 from hvad.forms import translatable_inlineformset_factory
-from hvad.forms import TranslatableModelForm, TranslatableModelFormMetaclass
 from hvad.test_utils.context_managers import LanguageOverride
 from hvad.test_utils.testcase import NaniTestCase
 from hvad.test_utils.request_factory import RequestFactory
-from testproject.app.models import Normal, Related
-from django.db import models
+from hvad.test_utils.project.app.models import Normal, Related
 
 class TestBasicInline(NaniTestCase):
     def setUp(self):
@@ -27,4 +25,4 @@ class TestBasicInline(NaniTestCase):
             self.assertTrue(formset.forms[0].fields.has_key("normal"))
             self.assertTrue(formset.forms[0].fields.has_key("translated"))
             self.assertTrue(formset.forms[0].fields.has_key("translated_to_translated"))
-            self.assertFalse(formset.forms[0].fields.has_key("language_code"))
\ No newline at end of file
+            self.assertFalse(formset.forms[0].fields.has_key("language_code"))
